@@ -100,8 +100,7 @@ test.path.rel2abs <- function()
 "e:/home/leslie/x.r"        "/tmp"  "e:/home/leslie/x.r"
 "leslie/leslie/../../irace" "/tmp"  "/tmp/irace"
 "x.r"                       "/tmp"  "/tmp/x.r"
-"~/../x.r"                  "/tmp"  "/home/x.r"
-"~/irace/../../x.r"         "/tmp"  "/home/x.r"
+"~/irace/../x.r"            "/tmp"  "~/x.r"
 "~/x.r"                     "/tmp"  "~/x.r"
 "../../../data"             "./"    "/data"
 "../../../data"             "/tmp/a/b/c/" "/tmp/data"
